##Dizzy je zamknutý v jaskyni, pomôž mu!!

1. Vytvorenie sveta
2. Vytvorenie dizzyho
3. pohyb dizzyho
4. vytvorenie batoha
5. vlozenie itemu do batoha
6. pouzitie itemov
7. Dizzy je volny

###Bonus
1. Ak dizzy prejde cez fakľu, zoberie mu to zivot


